summaryrefslogtreecommitdiffstats
path: root/korn/boxcontaineritem.h
diff options
context:
space:
mode:
Diffstat (limited to 'korn/boxcontaineritem.h')
-rw-r--r--korn/boxcontaineritem.h24
1 files changed, 13 insertions, 11 deletions
diff --git a/korn/boxcontaineritem.h b/korn/boxcontaineritem.h
index 06c02993..5393852a 100644
--- a/korn/boxcontaineritem.h
+++ b/korn/boxcontaineritem.h
@@ -41,19 +41,21 @@ class TQString;
* @author Mart Kelder <mart.kde@hccnet.nl>
*/
class BoxContainerItem : public AccountManager, public DCOPObject
-{ Q_OBJECT
+{
+ Q_OBJECT
+// TQ_OBJECT
K_DCOP
public:
/**
- * Standaard QObject-constuctor
+ * Standaard TQObject-constuctor
* This constructor implements the default arguments for any TQObject.
* Note that is does not give a name to DCOPObject; that name
* is set in the readConfig-function.
* @param parent The parent of this object, See Object::QObject
* @param name The name of this object, See TQObject::QObject
* @see BoxContainerItem::readConfig
*/
- BoxContainerItem( TQObject * parent = 0, const char * name = 0 );
+ BoxContainerItem( TQObject * tqparent = 0, const char * name = 0 );
/**
* The default destructor. This only removes _command-pointer.
@@ -68,7 +70,7 @@ public:
/**
* This function reads the config. It stores the readed values in the class.
* It also sets the DCOPObject-name.
- * @param config The KConfigGroup-object which tqcontains the configuration of this box.
+ * @param config The KConfigGroup-object which contains the configuration of this box.
* @param index The index of the box used in the config-file
*/
virtual void readConfig( KConfig* config, const int index );
@@ -105,14 +107,14 @@ public slots:
* This functions should be called if a mouse-button has been pressed.
* This handles the connected events of it.
*
* @param button The button that was pressed, See Qt::ButtonState
*/
- void mouseButtonPressed( Qt::ButtonState button );
+ void mouseButtonPressed( TQt::ButtonState button );
protected:
/**
* This function filles a KPopupMenu-reference. The target is
* to set in all implementations the same KPopupMenu-content.
* Because some implementations (DockedItem) got a KPopupMenu
* by itself, this only changes a KPopupMenu instance.
* @param menu The menu to be changed.
* @param actions The actions to which the items should be added.
@@ -122,13 +124,13 @@ protected:
/**
* This displays the passive popup.
*
* @param parent The Winget of the visual widget
* @param list List with the first (five) subjects
* @param total The total numbers of unread mail
* @param accountName The name of the account it belongs to
* @param date Should the date be displayed?
*/
- void showPassivePopup( TQWidget* parent, TQPtrList< KornMailSubject >* list, int total, const TQString& accountName, bool date );
+ void showPassivePopup( TQWidget* tqparent, TQPtrList< KornMailSubject >* list, int total, const TQString& accountName, bool date );
//this functions should be reimplemented
/**
@@ -41,19 +41,21 @@ class TQString;
* Note that is does not give a name to DCOPObject; that name
* is set in the readConfig-function.
- * @param parent The parent of this object, See Object::QObject
- * @param name The name of this object, See TQObject::QObject
+ * @param tqparent The tqparent of this object, See Object::TQObject
+ * @param name The name of this object, See TQObject::TQObject
* @see BoxContainerItem::readConfig
*/
@@ -105,14 +107,14 @@ public slots:
* This handles the connected events of it.
*
- * @param button The button that was pressed, See Qt::ButtonState
+ * @param button The button that was pressed, See TQt::ButtonState
*/
@@ -105,14 +107,14 @@ public slots:
* This function filles a KPopupMenu-reference. The target is
* to set in all implementations the same KPopupMenu-content.
- * Because some implementations (DockedItem) got a KPopupMenu
+ * Because some implementations (TQt::DockedItem) got a KPopupMenu
* by itself, this only changes a KPopupMenu instance.
* @param menu The menu to be changed.
@@ -122,13 +124,13 @@ protected:
* This displays the passive popup.
*
- * @param parent The Winget of the visual widget
+ * @param tqparent The Winget of the visual widget
* @param list List with the first (five) subjects
* @param total The total numbers of unread mail